==> project-api-0.9.2-sources.jar: org/gephi/project/spi/WorkspaceBytesPersistenceProvider.java <==
/*
 Copyright 2008-2010 Gephi
 Authors : Mathieu Bastian <mathieu.bastian@gephi.org>
 Website : http://www.gephi.org

 This file is part of Gephi.

 DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.

 Copyright 2011 Gephi Consortium. All rights reserved.

 The contents of this file are subject to the terms of either the GNU
 General Public License Version 3 only ("GPL") or the Common
 Development and Distribution License("CDDL") (collectively, the
 "License"). You may not use this file except in compliance with the
 License. You can obtain a copy of the License at
 http://gephi.org/about/legal/license-notice/
 or /cddl-1.0.txt and /gpl-3.0.txt. See the License for the
 specific language governing permissions and limitations under the
 License.  When distributing the software, include this License Header
 Notice in each file and include the License files at
 /cddl-1.0.txt and /gpl-3.0.txt. If applicable, add the following below the
 License Header, with the fields enclosed by brackets [] replaced by
 your own identifying information:
 "Portions Copyrighted [year] [name of copyright owner]"

 If you wish your version of this file to be governed by only the CDDL
 or only the GPL Version 3, indicate your decision by adding
 "[Contributor] elects to include this software in this distribution
 under the [CDDL or GPL Version 3] license." If you do not indicate a
 single choice of license, a recipient has the option to distribute
 your version of this file under either the CDDL, the GPL Version 3 or
 to extend the choice of license to its licensees as provided above.
 However, if you add GPL Version 3 code and therefore, elected the GPL
 Version 3 license, then the option applies only if the new code is
 made subject to such option by the copyright holder.

 Contributor(s):

 Portions Copyrighted 2011 Gephi Consortium.
 */
package org.gephi.project.spi;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import org.gephi.project.api.Workspace;

/**
 * Binary Workspace persistence provider.
 */
public interface WorkspaceBytesPersistenceProvider extends WorkspacePersistenceProvider {

    /**
     * This is automatically called when saving a project file.
     *
     * @param stream DataOutputStream stream to write to
     * @param workspace current workspace being serialized
     */
    public void writeBytes(DataOutputStream stream, Workspace workspace);

    /**
     * This is automatically called when loading a project file.
     *
     * @param stream DataInputStream stream to read from
     * @param workspace current workspace being deserialized
     */
    public void readBytes(DataInputStream stream, Workspace workspace);
}

==> project-api-0.10.1-sources.jar: org/gephi/project/spi/WorkspaceBytesPersistenceProvider.java <==
/*
 Copyright 2008-2010 Gephi
 Authors : Mathieu Bastian <mathieu.bastian@gephi.org>
 Website : http://www.gephi.org

 This file is part of Gephi.

 DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.

 Copyright 2011 Gephi Consortium. All rights reserved.

 The contents of this file are subject to the terms of either the GNU
 General Public License Version 3 only ("GPL") or the Common
 Development and Distribution License("CDDL") (collectively, the
 "License"). You may not use this file except in compliance with the
 License. You can obtain a copy of the License at
 http://gephi.org/about/legal/license-notice/
 or /cddl-1.0.txt and /gpl-3.0.txt. See the License for the
 specific language governing permissions and limitations under the
 License.  When distributing the software, include this License Header
 Notice in each file and include the License files at
 /cddl-1.0.txt and /gpl-3.0.txt. If applicable, add the following below the
 License Header, with the fields enclosed by brackets [] replaced by
 your own identifying information:
 "Portions Copyrighted [year] [name of copyright owner]"

 If you wish your version of this file to be governed by only the CDDL
 or only the GPL Version 3, indicate your decision by adding
 "[Contributor] elects to include this software in this distribution
 under the [CDDL or GPL Version 3] license." If you do not indicate a
 single choice of license, a recipient has the option to distribute
 your version of this file under either the CDDL, the GPL Version 3 or
 to extend the choice of license to its licensees as provided above.
 However, if you add GPL Version 3 code and therefore, elected the GPL
 Version 3 license, then the option applies only if the new code is
 made subject to such option by the copyright holder.

 Contributor(s):

 Portions Copyrighted 2011 Gephi Consortium.
 */

package org.gephi.project.spi;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import org.gephi.project.api.Workspace;

/**
 * Binary Workspace persistence provider.
 */
public interface WorkspaceBytesPersistenceProvider extends WorkspacePersistenceProvider {

    /**
     * This is automatically called when saving a project file.
     *
     * @param stream    DataOutputStream stream to write to
     * @param workspace current workspace being serialized
     */
    void writeBytes(DataOutputStream stream, Workspace workspace);

    /**
     * This is automatically called when loading a project file.
     *
     * @param stream    DataInputStream stream to read from
     * @param workspace current workspace being deserialized
     */
    void readBytes(DataInputStream stream, Workspace workspace);
}
